@@ -42,14 +42,14 @@ use JetBrains\PhpStorm\Internal\PhpStormStubsElementAvailable;
  * @param int $retries [optional] <p>
  * Number of maximum connect attempts
  * </p>
- * @param null|array $options [optional] <p>
+ * @param null|array $options <p>
  * Connection parameters, the following (string) keys maybe used
  * to set one or more connection parameters:
  * DISABLE_AUTHENTICATOR - Disable authentication properties</p>
  * @return resource|false an IMAP stream on success or <b>FALSE</b> on error.
  */
 #[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection|false'], default: 'resource|false')]
-function imap_open(string $mailbox, string $user, string $password, int $flags = 0, int $retries = 0, array $options = null) {}
+function imap_open(string $mailbox, string $user, string $password, int $flags = 0, int $retries = 0, array $options = []) {}
 
 /**
  * Reopen IMAP stream to new mailbox
@@ -510,7 +510,7 @@ function imap_expunge(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], def
  * Mark a message for deletion from current mailbox
  * @link https://php.net/manual/en/function.imap-delete.php
  * @param resource $imap
- * @param string $message_num <p>
+ * @param string $message_nums <p>
  * The message number
  * </p>
  * @param int $flags [optional] <p>
@@ -520,19 +520,19 @@ function imap_expunge(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], def
  * </p>
  * @return bool <b>TRUE</b>.
  */
-function imap_delete(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap, string $message_num, int $flags = 0): bool {}
+function imap_delete(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap, string $message_nums, int $flags = 0): bool {}
 
 /**
  * Unmark the message which is marked deleted
  * @link https://php.net/manual/en/function.imap-undelete.php
  * @param resource $imap
- * @param string $message_num <p>
+ * @param string $message_nums <p>
  * The message number
  * </p>
  * @param int $flags [optional]
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function imap_undelete(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap, string $message_num, int $flags = 0): bool {}
+function imap_undelete(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap, string $message_nums, int $flags = 0): bool {}
 
 /**
  * Check current mailbox
@@ -926,11 +926,18 @@ function imap_clearflag_full(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection
  * following:
  * <b>SE_UID</b> - Return UIDs instead of sequence numbers</p>
  * @param string $search_criteria [optional]
- * @param string $charset [optional]
+ * @param string $charset
  * @return array|false an array of message numbers sorted by the given
  * parameters.
  */
-function imap_sort(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap, int $criteria, bool $reverse, int $flags = 0, ?string $search_criteria = null, ?string $charset = 'NIL'): array|false {}
+function imap_sort(
+    #[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap,
+    int $criteria,
+    bool $reverse,
+    int $flags = 0,
+    ?string $search_criteria = null,
+    ?string $charset = null
+): array|false {}
 
 /**
  * This function returns the UID for the given message sequence number
@@ -1080,14 +1087,19 @@ function imap_last_error(): string|false {}
  * <b>SE_UID</b>, which causes the returned array to
  * contain UIDs instead of messages sequence numbers.
  * </p>
- * @param string $charset [optional]
+ * @param string $charset
  * @return array|false an array of message numbers or UIDs.
  * <p>
  * Return <b>FALSE</b> if it does not understand the search
  * <i>criteria</i> or no messages have been found.
  * </p>
  */
-function imap_search(#[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap, string $criteria, int $flags = SE_FREE, string $charset = NIL): array|false {}
+function imap_search(
+    #[LanguageLevelTypeAware(['8.1' => 'IMAP\Connection'], default: 'resource')] $imap,
+    string $criteria,
+    int $flags = SE_FREE,
+    string $charset = ""
+): array|false {}
 
 /**
  * Decodes a modified UTF-7 encoded string
